#from . import gapped_kmer #don't want to auto-import tensorflow
from . import advanced_gapped_kmer
from . import onehot_model_output
